#
# spec file for package baloo5
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           baloo5
Version:        5.116.0
Release:        1.4
Summary:        Framework for searching and managing metadata
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND LGPL-3.0-only
URL:            https://www.kde.org
Source:         baloo-%{version}.tar.xz
%if %{with released}
Source1:        baloo-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  libattr-devel
BuildRequires:  lmdb-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5Crash) >= %{_kf5_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5FileMetaData) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(KF5IdleTime) >= %{_kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_version}
BuildRequires:  cmake(KF5Solid) >= %{_kf5_version}
BuildRequires:  cmake(Qt5Concurrent) >= %{qt5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Qml) >= %{qt5_version}
BuildRequires:  cmake(Qt5Quick) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}

%description
Baloo is a framework for searching and managing metadata.

%package -n libKF5Baloo5
Summary:        Core library for Baloo Framework

# The -lang package was split into components
Provides:       %{name}-lang = %{version}
Obsoletes:      %{name}-lang < %{version}
# baloo5-imports-lang is gone in 5.83
Obsoletes:      %{name}-imports-lang < 5.83

%description -n libKF5Baloo5
Baloo is a framework for searching and managing metadata. This
package contains Baloo's core library.

%package -n libKF5BalooEngine5
Summary:        Baloo Engine library
Recommends:     libKF5BalooEngine5-lang

%description -n libKF5BalooEngine5
Baloo is a framework for searching and managing metadata. This
package contains Baloo's Engine library.

%package file
Summary:        Filesearch components for Baloo Framework
Requires:       libQt5Sql5-sqlite
Recommends:     %{name}-file-lang
Provides:       baloo-file = %{version}
Obsoletes:      baloo-file < %{version}

%description file
Baloo is a framework for searching and managing metadata. This
package contains filesearch components.

%package kioslaves
Summary:        KIO slave components for Baloo Framework
Requires:       kded
Recommends:     %{name}-kioslaves-lang

%description kioslaves
Baloo is a framework for searching and managing metadata. This
package contains KIO slave components.

%package tools
Summary:        Aditional components for Baloo Framework
Recommends:     %{name}-tools-lang
Provides:       baloo-tools = %{version}
Obsoletes:      baloo-tools < %{version}

%description tools
Baloo is a framework for searching and managing metadata. This
package contains aditional command line utilities.

%package imports
Summary:        QML components for Baloo Framework
Recommends:     %{name}-imports-lang

%description imports
Baloo is a framework for searching and managing metadata. This
package contains QML imports.

%package devel
Summary:        Development package for baloo5
Requires:       libKF5Baloo5 = %{version}
Requires:       libKF5BalooEngine5 = %{version}
Requires:       lmdb-devel
Requires:       cmake(KF5CoreAddons) >= %{_kf5_version}
Requires:       cmake(KF5FileMetaData) >= %{_kf5_version}
Requires:       cmake(Qt5Core) >= %{qt5_version}
# DBus interface file
Conflicts:      baloo-devel

%description devel
Baloo is a framework for searching and managing metadata. This
package contains aditional command line utilities. Development files.

%lang_package -n libKF5BalooEngine5
%lang_package -n %{name}-file
%lang_package -n %{name}-tools
%lang_package -n %{name}-kioslaves
%lang_package -n %{name}-imports

%prep
%autosetup -p1 -n baloo-%{version}

%build
%cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
%cmake_build

%install
%kf5_makeinstall -C build

%{kf5_find_lang}
# Split manually, kf5_find_lang doesn't support it...
grep -E '^%%dir' %{name}.lang | tee %{name}-{file,tools,kioslaves}.lang >/dev/null
grep -E '/balooengine5.mo$' %{name}.lang >> libKF5BalooEngine5.lang
grep -E '/(balooctl5|baloo_file5|baloo_file_extractor5).mo$' %{name}.lang >> %{name}-file.lang
grep -E '/(baloodb5|baloosearch5|balooshow5).mo$' %{name}.lang >> %{name}-tools.lang
grep -E '/(kio5_baloosearch|kio5_tags|kio5_timeline).mo$' %{name}.lang >> %{name}-kioslaves.lang


rm %{name}.lang

%ldconfig_scriptlets -n libKF5Baloo5

%post file %{systemd_user_post kde-baloo.service}
%preun file %{systemd_user_preun kde-baloo.service}
%postun file %{systemd_user_postun kde-baloo.service}

%ldconfig_scriptlets -n libKF5BalooEngine5

%files -n libKF5Baloo5
%license LICENSES/*
%{_kf5_libdir}/libKF5Baloo.so.*

%files -n libKF5BalooEngine5
%{_kf5_libdir}/libKF5BalooEngine.so.*

%files file
%{_kf5_bindir}/baloo_file
%{_kf5_bindir}/baloo_file_extractor
%{_kf5_bindir}/balooctl
%{_kf5_configdir}/autostart/baloo_file.desktop
%{_kf5_debugdir}/baloo.categories
%{_kf5_debugdir}/baloo.renamecategories
%{_libexecdir}/baloo_file
%{_libexecdir}/baloo_file_extractor
%{_userunitdir}/kde-baloo.service

%files kioslaves
%dir %{_kf5_plugindir}/kf5/kded
%{_kf5_plugindir}/kf5/kded/baloosearchmodule.so
%dir %{_kf5_plugindir}/kf5/kio
%{_kf5_plugindir}/kf5/kio/baloosearch.so
%{_kf5_plugindir}/kf5/kio/tags.so
%{_kf5_plugindir}/kf5/kio/timeline.so

%files tools
%{_kf5_bindir}/baloosearch
%{_kf5_bindir}/balooshow

%files imports
%{_kf5_qmldir}/

%files devel
%{_kf5_includedir}/Baloo/
%{_kf5_libdir}/cmake/KF5Baloo/
%{_kf5_libdir}/libKF5Baloo.so
%{_kf5_libdir}/pkgconfig/Baloo.pc
%{_kf5_mkspecsdir}/qt_Baloo.pri
%{_kf5_sharedir}/dbus-1/interfaces/*.xml

%files -n libKF5BalooEngine5-lang -f libKF5BalooEngine5.lang

%files file-lang -f %{name}-file.lang

%files tools-lang -f %{name}-tools.lang

%files kioslaves-lang -f %{name}-kioslaves.lang

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- Changes since 5.113.0:
  * [IndexCleaner] Remove no-op recursion over includedFolders
  * [ExtractorProcess] Remove unused members
  * [TimeEstimator] Cleanup, remove QObject depency
  * Use forward declaration for Baloo::Database
  * Remove inacurate mimetype check in xattrindexer and indexcleaner
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- Changes since 5.112.0:
  * Remove two obsolete benchmark tests
  * [ExtractorProcess] Handle signal mangling by DrKonqi
  * [ExtractorProcess] Test the various processing states
  * [ExtractorProcess] Make the extractor process path a constructor argument
  * [BasicIndexingBenchmark] Allow to keep temporary DB
  * [QueryTest] Add test case for terms folded to empty strings
  * [DocumentUrlDb] Reduce allocations during path reconstruction
  * Shortcut non-matching phrase queries
  * [EngineQuery] Remove AND/OR operations
  * [QueryTest] Move AND/OR queries to searchstring tests
  * [QueryParser] Remove it, as it is no longer used
  * [SearchStore] Always use TermGenerator instead of QueryParser
  * [Extractor] Do not emit startedIndexingFile for skipped documents
  * Remove dead registerBalooWatcher DBus method
  * [FileWatchTest] Check attr changed signal when XAttr is not available
  * [FileWatchTest] Clean up and enhance result checks
  * [FileWatchTest] Replace common boilerplate with RAII
  * [KInotify] Fix _k_addWatches helper when hitting descriptor limit
  * [KInotify] Simplify dirIter logic, use unique_ptr
  * [KInotify] Always add all watches in the event loop
  * [KInotifyTest] Extend renaming tests
  * [KInotifyTest] Move common boilerplate to init
  * [KInotify] Silence EventMoveSelf warning when not relevant
  * [KInotify] Removed unused and obsolete `available()` method
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- Changes since 5.111.0:
  * [PendingFile] Remove default constructor, METATYPE declaration
  * [PendingFile] Remove unused and incorrect setPath method
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- Changes since 5.110.0:
  * Use the FSID as the device identifier where possible (kde#402154)
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Document uses and abuses of Baloo::IndexerConfig
  * [BalooSearch] Add sort order option
  * [Codecs] Make encode/decode methods static, cleanup
  * [QueryTest] Add full stack test
  * [TermGeneratorTest] Extend phrase coverage
  * [AdvancedQueryParserTest] Extend phrase coverage
  * [SearchStore] Move private helpers to anonymous namespace
  * [BasicIndexingJob] Ignore filename based mimetype for empty files
  * Reduce filesystem dependencies in more tests
  * [DocumentUrlDbTest] Remove file system dependencies from test
  * [DocumentUrlDb] Split document addition and file tree creation
  * [DocumentUrlDbTest] Use explicit recursion when walking directory tree
  * [Transaction] Use DocumentUrlDB::contains
  * [DocumentUrlDB] Add `contains` method
  * Remove proxy for obsolete org.kde.baloo interface
  * [Transaction] Remove Transaction::exec convenience method
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * [Document] Fix parameter name for setParentId
  * [WriteTransaction] Avoid false warning when removing empty xattr terms
  * [DocumentUrlDB] Remove recursive removal of parent directories
  * [AdvancedQueryParser] Correctly parse empty quoted strings
  * [AdvancedQueryParser] Fix minor error in test case
  * Remove qt6 CI builds
  * [UnindexedFileIndexer] Split into multiple transactions
  * [FirstRunIndexer] Split initial index run into multiple transactions
  * Move basic indexing test/benchmark to autotests
  * [BasicIndexingTest] Add options for transaction size and index dir
  * [WriteIoTest] Set required parent id
  * Minor fixes for manual tests
  * Fix signedness mismatch compiler warning
  * Fix compiler warning by using an STL-style iterator instead
  * Remove redundant transactiontest
  * [UnindexedFileIndexer] Skip document when BasicIndexingJob fails
  * [Transaction] Allow to fully reset the transaction state
  * [WriteTransactionTest] Use unique_ptr for DB and temp dir
  * [Transaction] Use unique_ptr for write transaction
  * Verify parentId when adding documents
  * [DatabaseDbis] Use default member initializers instead of constructor
  * Remove unused QMimeDatabase instance from UnindexedFileIndexer
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- Changes since 5.106.0:
  * Use common helper for Property/JSON conversion
  * Don't install D-Bus interfaces without BUILD_INDEXER_SERVICE
  * Make building of the service optional, add packaging documentation
  * Minor fixes for DocumentUrlDB::updateUrl method
  * [IdTreeDB] Consolidate put/del into common set
  * [MetadataMoverTest] Add some more test documentation
  * Remove dead code paths from DocumentUrlDB::del
  * Cleanup some leftover stale code
  * Use more RAII in unit tests
  * port to standard C++ smart pointers where possible
  * Add some documentation for DocumentDB/DocumentIdDB
  * [balooshow] Improve display of property and plaintext terms
  * Move KFileMetaData documentation reference up
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * baloosearch: Inform the user when the specified dir is not canonical
  * aggressively resource constrain baloo_file
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- Changes since 5.104.0:
  * Add conventional python virtual-env folder to exclude filters
  * [TermGenerator] Skip all unprintable characters
  * Define the translation domain of BalooEngine
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * extactor: add KAboutData
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * Fix automoc issues on generated DBus source files
  * Don't skip automoc for DBus interfaces
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- No code change since 5.101.0
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * Change KIO worker logging categories to kf.kio.workers.*
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * [TermGeneratorTest] Reduce code duplication
  * Correct and simplify OrpostingIterator constructor
  * Convert kded metadata to JSON
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- No code change since 5.98.0
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add FreeBSD Qt6 CI support
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- No code change since 5.96.0
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- No code change since 5.95.0
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * tag:/ better handle uds name field (kde#449126)
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * [Timeline KIO] Don't announce that we can write
  * Require unittests to pass for CI jobs to pass
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- No code change since 5.92.0
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Use libc rename() calls rather than QFile to simulate renames
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%_libdir/libexec with %%_libexecdir (boo#1174075)
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Add Qt6 Linux CI
  * Static libs linked into shared libs need -fPIC
  * Fix KFileMetaData::PropertyMap related Qt6 build issues
  * install in kf<version>
  * now exec line is not usefull
  * Use camel case include
  * Add missing include (qt6)
  * engine/idutils.h - fix compile in filePathToStat
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Adapt build system for building against qt6
  * [kioslaves/tags] Set proper display name for root entry (kde#416389)
  * Port away from deprecated QMap::insertMulti & related KFileMetadata API
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Port QStringRef (deprecated) to QStringView
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Fix wrong markup for second-level bullets
  * Add FreeBSD CI
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Native Gitlab CI configuration
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * We depend against c++-17 so we can use qOverload directly
  * Use const'ref
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Mention the https://community.kde.org/Baloo pages in README file
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Update IRC network name in the README
- Only install the license files once
* Sun Jun 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Uninstall baloo5-imports-lang when installing baloo5 5.83.0
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Embed JSON metadata in KIOSlaves
  * Remove obsolete .protocol files
  * Convert protocol files to JSON
  * Fix Mesasges.sh by removing path
  * Bump required CMake version to 3.16
  * Remove SUSE Qt5.14 build status
  * [balooctl] Allow clearing a document which has been deleted
  * [DocumentUrlDB] Remove unused function
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Too many changes since 5.81.0, only listing bugfixes:
  * Do not crash when a dir is move/delete is detected by
    kinotify (kde#435143)
  * When adding a folder to configuration, normalize the path
    semantically (kde#434919)
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * [SearchStore] Explicitly narrow timestamps for range query
  * Add now mandatory args parameter to QProcess::startDetached()
  * Port away from deprecated QDateTime(QDate) constructor
  * Remove long defunct, xapian based filesearchstoretest
  * Remove unused fileinfo.cpp/.h
  * [MetadataMover] Update filename terms when moving/renaming file (kde#433116)
  * [MetadataMover] Extend renaming test cases
  * [MetadataMover] Use categorized logging for all debug statements
  * [MetadataMover] Make some temporaries const
  * Add trailing commas to enums
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * [balooshow] Always print parsed document/device/inode id
  * [balooshow] Allow hexadecimal format for deviceid parameter
  * [baloosearch] Allow to print document ID
  * [ResultIterator] Provide document ID
  * [ResultIterator] Rework for future extension
  * Don't try to index ninja files
  * Don't try to index .swp files (kde#433095)
  * Add .gitlab-ci.yml to enable CI
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Too many changes to list here.
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * [ExtractorProcess] Move DBus signal from helper to main process
  * [timeline] Consolidate code for root folder stat and list
  * Remove unnecesary KIO/Job include
  * Make toplevel ioslave UDS entries readonly
  * avoid errors for application startup if no baloo index was ever created
  * Remove ifdefs, we require Qt 5.14 now
  * [BasicIndexingJob] Strip trailing slash from folders
  * Add Buildstatus badges for SUSE Qt5.14 and FreeBSD
  * Fix internal link to "Searching" user documentation
- Drop 0001-BasicIndexingJob-Strip-trailing-slash-from-folders.patch
* Sat Dec 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix a regression causing empty results (kde#430273):
  0001-BasicIndexingJob-Strip-trailing-slash-from-folders.patch
* Sat Dec  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Too many changes to list here.
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Split CJK terms at punctuation characters, optimize code
  * Refactor the code in preparation for ICU integration.
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Remove not implemented method
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Too many changes to list here.
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Too many changes since 5.73.0, only listing bugfixes:
  * Use common UDS creation code also for tags (kde#419429)
  * Don't index .ytdl files (kde#424925)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * [Indexers] Ignore name-based mimetype for initial indexing decisions
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * baloo: fix unused variables
  * Store filename terms just once
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Too many changes to list here.
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Too many changes to list here.
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * [FileContentIndexer] Remove duplicate condition check for loop break
  * [ModifiedFileIndexer] Correct time checks for new files
  * [ModifiedFileIndexer] Omit BasicIndexingJob run when not required
  * [tools] Clean up messed up whitespace
  * Fix minor EBN issues (http->https)
  * Extract messages from header file as well
  * Sync IndexerConfig on exit (kde#417127)
  * Use ecm_qt_install_logging_categories over manual categories file
  * [FileIndexScheduler] Force evaluation of indexerState after suspend/resume
- Drop upstream patches:
  * 0001-FileIndexScheduler-Force-evaluation-of-indexerState-.patch
  * Sync-IndexerConfig-on-exit.patch
* Tue Feb 18 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix FileIndexScheduler being stuck after suspending it:
  0001-FileIndexScheduler-Force-evaluation-of-indexerState-.patch
* Sat Feb 15 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add Sync-IndexerConfig-on-exit.patch to fix settings not getting
  saved (kde#417127)
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Migrate config from KConfig to KConfigXt in order to allow KCM to use it
  * Fix minor typos
  * Port endl to \n or std::cout/cerr as in qt5.15 endl is Qt:: namespaced
  * Port QRegExp to QRegularExpression
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * QAtomicInteger::loadRelaxed() and storeRelaxed() are available since Qt 5.14
  * Delete icon
  * Port to QRandomGenerator
  * Correctly report if baloo_file is unavailable
  * Port away from Qt 5.14 deprecated QList methods
  * Check cursor_open return value
  * Initialise QML monitor values
  * Update the obsolete projects.kde.org URL
  * Move URL parsing methods from kioslave to query object
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- No code change since 5.64.0
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Make it compile against qt5.15
  * Use ECMGenerateExportHeader to manage deprecated API better
  * Use propertymap to store properties in Baloo::Result
  * Add standalone conversion functions for PropertyMap to Json and vice versa
  * Add a few const &
  * [Database] Rework handling environment flags
  * Replace recursion in FilteredDirIterator with loop iteration
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Small performance improvements suggested by clang-tidy
  * Port away from deprecated API in Qt 5.14
  * Port away from deprecated methods in Qt 5.14
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Fixes a crash in Peruse triggered by baloo
  * Fix section hierachy in distributing.md
  * Remove unused includes
  * [kded/baloosearchmodule] Remove useless qDebug messages
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Remove extra ";"
  * [tags] Fix coding style
  * Add KDevelop files to gitignore
  * Link against KIOCore instead of KIOWidgets in kioslaves
  * [IndexCleaner] ignore non-existent entries inside config
* Wed Aug  7 2019 wbauer@tmo.at
- Drop fix-cmakelists-comments.diff as well, it cannot be built
  with cmake 2.x anymore since a long time
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop patch to support Qt 5.9:
  * 0001-Do-not-use-qfileinfo-metadatachangetime-if-Qt-lt-5.10.patch
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Too many changes to list here
- Refreshed patches:
  * 0001-Do-not-use-qfileinfo-metadatachangetime-if-Qt-lt-5.10.patch
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Don't try to index SQL database dumps
  * Exclude .gcode and virtual machine files from indexing consideration
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * [baloo_file] Wait for extractor process to start
  * [balooctl] Add command to show files failed to index
  * Add QML to source code types
  * [Transaction] Minor code cleanup/optimization
  * [balooctl] Capture the constant totalsize in the lambda
  * [balooctl] Switch multiline output to new helper
  * [balooctl] Use new helper in json output
  * [balooctl] Use new helper for simple format output
  * [balooctl] Factor out file index status collection from output
  * Keep empty Json metadata docs out of DocumentData DB
  * [balooshow] Allow referencing files by URL from hardlink
  * [balooshow] Suppress warning when URL refers to unindexed file
  * Simplify orPostingIterator and make it faster
  * Ensure QFileInfo is valid for the first FilteredDirIterator entry
  * [MTimeDB] Allow timestamp newer than the newest document in range match
  * [MTimeDB] Use exact match when exact match is requested
  * [balooctl] Cleanup handling of different positional arguments
  * [balooctl] Extend options help text, improve error checking
  * [balooctl] Use more understandable names for size in status output
  * [balooctl] clear command: Remove bogus check for documentData, cleanup
  * [kio_search] Fix warning, add UDSEntry for "."  in listDir
  * Use hex notation for DocumentOperation flag enum
  * Calculate total DB size correctly
  * Postpone term parsing until needed, do not set both term and searchstring
  * Dont add default valued date filters to json
  * Use compact Json format when converting query URLs
  * [balooshow] Do not print a bogus warning for a non-indexed file
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * [DocumentIdDB] Silence non-error debug message, warn on errors
  * [baloosearch] Allow specifying a time when using e.g. mtime
  * [indexcleaner] Avoid removing included folders below excluded ones
  * [MTimeDB] Add some tests which include a 0 mtime
  * [MTimeDB] Fix lookup for the LessEqual range
  * [MTimeDB] Fix lookup when time range should return empty set
  * Correct asserts/error handling in MTimeDB
  * Protect against invalid parents in the IdTreeDB
  * Remove document from MTimeDB/DocumentTimeDB even when timestamp is 0
  * Be more precise with mimetype detection
  * [timeline] Canonicalize Url
  * [timeline] Fix missing/misplaced SlaveBase::finished() calls
  * [balooshow] Several extensions to basic file information output
  * [timeline] Fix warning, add missing UDS entry for "."
  * [balooctl] Reduce nesting level for addOption arguments, cleanup
  * Properly fix copy constructor
  * React to config updates inside indexer (kde#373430)
  * Fix regression when opening DB in read-write mode
  * [baloo] make it compile without foreach
  * [balooctl] Cleanup trailing whitespace
  * [engine] Unbreak code, revert renaming of Transaction::abort()
  * Harmonize handling of underscore in query parser
  * Baloo engine: treat every non-success code as a failure
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Replace several Q_ASSERTs with proper checks
  * Check string length to avoid crash for "tags:/" URL
  * [tags_kio] Fix local file tagging by checking only tag: urls for double slashes.
  * add baloo engine debugging category
  * Hardcoding the Remaining Time Update Interval
  * Fix regression for matching explicitly included folders
  * Cleanup idempotent entries from mimetype mapper table
  * [baloo/KInotify] Notify if folder was moved from unwatched place (kde#342224)
  * Simplify term debug output
  * Handle folders matching substrings of included/excluded folders correctly
  * [balooctl] Normalize include/exclude pathes before using it for the config
  * Optimize Baloo::File copy assign operator, fix Baloo::File::load(url)
  * Use content to determine mime type
  * Get rid of mostly unused filePathToStat overload
  * [Extractor] Exclude GPG encrypted data from being indexed
  * [balooctl] Actually abort a malformed command instead of just saying so
  * [balooctl] Add missing help for "config set", normalize string
  * Replace recursive isDirHidden with iterative one, allow const argument
  * Make sure only directories are added to the inotify watcher
- Dropped patches, now upstream:
  * 0001-Check-string-length-to-avoid-crash-for-tags-URL.patch
* Wed Feb 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix crashing kdeinit, add
  0001-Check-string-length-to-avoid-crash-for-tags-URL.patch
* Fri Feb 15 2019 alarrosa@suse.com
- Add 0001-Do-not-use-qfileinfo-metadatachangetime-if-Qt-lt-5.10.patch to
  revert a change by upstream that removes support for Qt < 5.10
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Fix ResultIterator
  * [tags_kio] Disable access with a double slashed url, i.e. "tags://". (kde#400594)
  * Instantiate QApplication before KCrash/KCatalog
  * Ignore all non-storage deviceAdded signals from Solid
  * IndexerConfig: Delete copy constructor and assignment operator
  * delete copy constructor and assignment operator of some internal classes
  * Use the nicer K_PLUGIN_CLASS_WITH_JSON
  * Remove Qt 5.10 checks now that we require it as min version
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Extend PositionCodec unit tests, better code coverage
  * Move typesForMimeType helper from BasicIndexingJob to anonymous namespace
  * Fix mistakes introduced in a632a72a
  * Don't check if file is directory based on mime-type
  * Fixed link to the coding style wiki page
  * add documentation to result class
  * Move internal helper from BasicIndexingJob to anonymous namespace
  * Add "image/svg" as Type::Image to the BasicIndexingJob
  * Minor optimization and cleanup for PositionCodec
  * Avoid potential nullptr access for Document, use reference instead
  * RFC: Add unit test for splitting of numbers in TermGenerator
  * Use Compact json formatting for storing document metadata
  * Remove unused map() getter from Result
  * remove unused docId from result
  * Use escaped UTF-8 sequence instead of Latin1 characters, minor cleanups
  * Treat uints the same as ints
  * Add unittest to check if commiting the same change twice works
  * Add unit test for position DB
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Remove duplicated code for rating property
  * Extend unit tests to check comparisons of multi-digit numeric properties
  * Fix searches for rating 10 (5 stars) (kde#357960)
  * Remove extra spaces from Debug output, insert delimiters between fields
  * Use isEmpty()
  * Avoid writing unchanged data to terms dbs
  * Reserve space in pending operations vector
  * Remove unused QByteArray include
  * Replace Latin1 character remnant with escaped UTF-8 sequence
  * Cleanup comments for MS Office mimetypes in typesForMimetype
  * Remove unused wdfInc parameter for addTerm and addPositionTerm
  * Use append instead of operator+= when appending to an QVector<int>
  * Do not add Type::Document/Presentation/Spreadsheet twice for MS Office docs
  * Add missing return in error/fixup path
  * actually initialize kcrash properly
  * Add unittest for document replacement
  * Make sure there is only one MTime per document in the MTimeDB
  * Extend diagnostic output for DB autotests
  * Use new syntax
  * [Extractor] Use QDataStream serialization in place of cooked one
  * [Extractor] Replace homegrown IO handler with QDataStream, catch HUP
  * Unbreak build with BUILD_QCH=TRUE
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Too many changes to list here
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Add calls to KIO::UDSEntry::reserve in timeline/tags ioslaves
  * [balooctl] Flush buffered "Indexing <file>" line when indexing starts
  * [FileContentIndexer] Connect finished signal from extractor process
  * [PositionCodec] Avoid crash in case of corrupt data (kde#367480)
  * Fix invalid char constant
  * [Balooctl] remove directory parent check (kde#396535)
  * Allow removing non-existent folders from include and exclude lists (kde#375370)
  * Use non deprecated fastInsert in baloo
  * Use String to store UDS_USER and UDS_GROUP of String type. (kde#398867)
  * [tags_kio] Fix parenthesis. Somehow this got by my code checker.
  * [tags_kio] Remove intermediate QString.
  * Use QString's multi-arg with multiple string args
  * Avoid potential detach on range-loops with non-const Qt containers
  * Compile with strict compile flags
  * Exclude genome files from indexing
  * Fix minor EBN issues
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Fixed a typo in the index size output (kde#397843)
  * Remove src not dest url when a url is newly unindexable.
  * [tags_kio] Simplify the filename path query matching by using a capture group.
  * Revert "Skip queueing newly unindexable files and remove them from the index immediately."
  * [tags_kio] Simplify file path lookup while loop.
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * [tags_kio] Clean up parser debug and comments.
  * [tags_kio] Fix multiple filename copies.
  * Revert "[tags_kio] Use UDS_URL instead of UDS_TARGET_URL."
  * [tags_kio] Use UDS_URL instead of UDS_TARGET_URL.
  * [tags_kio] Query target filepaths instead of appending paths to the file UDS entry.
  * Support special URLs for finding files of a certain type
  * Avoid manipulation of lists with quadratic complexity
  * Use non deprecated fastInsert in baloo
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Remove unused entry X-KDE-DBus-ModuleName from the kded plugin metadata
  * [tags_kio] The url query should be a key-value pair.
  * The power state signal should only be emitted when the power state changes.
  * baloodb: Make changes to cmdline arg description after rename prune -> clean
  * Clearly show duplicate filenames in tag folders.
* Thu Jun 14 2018 wbauer@tmo.at
- Recommend corresponding lang packages
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Terminate query execution early if subterm returns empty result set
  * Avoid crash when reading corrupt data from document terms db (kde#392878)
  * Use override
  * handle string lists as input
  * fix some issues reported by clazy
  * Ignore more types of source files (kde#394002, kde#390932)
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Avoid infinite loops when fetching the URL from DocumentUrlDB (kde#378754)
  * add missing license
  * add Baloo DBus signals for moved or removed files
  * Add missing override
  * Fix extract i18n from .h file
  * [API dox] Note CamelCase include commands for classes
  * Install pri file for qmake support & document it in metainfo.yaml
  * baloodb: Add clean command
  * balooshow: Colorize only when attached to terminal
  * Remove FSUtils::getDirectoryFileSystem
  * Avoid hardcoding of filesystems supporting CoW
  * Allow disabling of CoW to fail when not supported by filesystem
  * databasesanitizer: Use flags for filtering
  * Fix merging of terms in the AdvancedQueryParser
  * Use QStorageInfo instead of a homegrown implementation
  * sanitizer: Improve device listing
  * fix message ectraction by using find
  * Immediately apply termInConstruction when term is complete
  * Handle adjacent special characters correctly (kde#392620)
  * Add test case for parsing of double opening '(('
  * Fix another syntax error on windows build
  * Fix syntax error on windows build
  * Use statbuf consistently
* Tue Apr 17 2018 fabian@ritter-vogt.de
- Split baloo5-lang into subpackages
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Make list of subterms in debug output easier to spot
  * Simplify Term operator&& and ||
  * advancedqueryparsertest: Add more tests
  * Do not retrieve document ID for skipped result entries
  * Do not retrieve mtime from database repeatedly when sorting
  * Fix unitialized value warning, nullptr access
  * Do not export databasesanitizer by default
  * baloodb: Add experimental message
  * Introduce baloodb CLI tool
  * sanitizer: Move implementation into Baloo namespace
  * Introduce sanitizer class
  * autotests: Refactor fileindexerconfigtest
  * [FileIndexerConfig] Delay populating folders until actually used
  * src/kioslaves/search/CMakeLists.txt - link to Qt5Network following changes to kio
  * Remove not necessary QtCore and co
  * balooctl: checkDb should also verify the last known url for the documentId.
  * balooctl monitor: Resume to wait for service
  * autotest: port to QSignalSpy::wait().
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * balooctl: Remove checkDb option (kde#380465)
  * indexerconfig: Describe some functions
  * indexerconfig: Expose canBeSearched function
  * balooctl monitor: Wait for dbus interface
  * fileindexerconfig: Introduce canBeSearched()
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * baloo-tools: Make all output messages translatable
  * build baloo executables with "ecm_mark_nongui"
  * balooctl status: Produce parseable output
  * Fix KIO Slave tagged folder deep copies. This breaks listing tagged folders in the tag tree, but is better than broken copies.
  * Skip queueing newly unindexable files and remove them from the index immediately.
  * Revert "Changing file xattrs (tag, rating, comment) should cause a file to be reindexed. If the ctime changed, the file can be reindexed."
  * baloosearch: Send summary to stderr
  * balooctl status: translatable message
  * Delete newly unindexable moved files from the index.
  * Simplify BasicIndexingJob xattr indexing.
  * Changing file xattrs (tag, rating, comment) should cause a file to be reindexed. If the ctime changed, the file can be reindexed.
  * validate baloo_file.desktop
  * balooctl use global fileIndexDbPath().
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * balooctl status: process all arguments
  * Remove obsolete reviewboardrc file
  * Fix multiple word tag queries.
  * Simplify rename conditions.
  * Fix incorrect UDSEntry display name.
  * Make it compiles with autogenerated debug file
  * Revert "Revert "Autogenerate debug file""
  * Revert "Autogenerate debug file" I'm backing all of this out for now as fixing this properly is non-trivial and the build is broken on at least one platform due to this change.
  * Revert "Complete removal of references to baloodebug.cpp which was deleted in the previous commit"
  * Complete removal of references to baloodebug.cpp which was deleted in the previous commit
  * Autogenerate debug file
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Jenkins build fix. (type change)
  * Strip down and re-write the baloo tags KIO slave (kde#314373, kde#340098, kde#376229, kde#332214, kde#340099)
  * Remove unused config.h.cmake entries
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Consider DjVu files to be documents (kde#369195)
  * Fix spelling so WPS Office presentations are recognized correctly
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Don't enter test subdirectories if BUILD_TESTING=OFF
  * Only match real MIME types, not e.g. "raw CD image" (kde#364884)
  * Remove pf.path() from container before the reference got screwed up by it.remove()
  * Fix tags KIO-slave protocol description
  * Consider markdown files to be Documents
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Avoid useless copies from it.next(), add const REVIEW: 129378
  * Remove useless includes REVIEW: 129650
  * Fix directory based search.
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Fix compilation with cmake current git and cmake >= 3.10
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Use FindInotify.cmake to decide wheter inotify is available.
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Fix title of FAQ doc
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Rename the translation catalogs (avoid conflicts)
  * balooctl, baloosearch, balooshow: Fix order of QCoreApplication object creation (kde#378539)
  * balooshow: fix typo (kde#369470)
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Change some types and exclude filters
  * Added description for commands (balooctl)
  * Search also in symlinked directories
  * Fixed normalization/toLower order
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Implement nested tags. REVIEW: 128664
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Performance improvements when writing
    (4 * speedup for writing out data)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  9 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Use correct config entry in autostart condition
  * Fix sorted insert (aka flat_map like insert)
    (kde#367991)
  * Add missing close env, as pointed out by Loïc Yhuel
    (kde#353783)
  * Transaction not created => don't try to abort them
  * fix missing m_env = nullptr assignment
  * Make e.g. Baloo::Query thread safe
  * On 64-bit systems baloo allows now > 5 GB index storage
    (kde#364475)
  * Allow ctime/mtime == 0
    (kde#355238)
  * Handle corruption of index database for baloo_file, try to recreate the database or abort if that fails
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
- Drop upstreamed patches:
  0001-fix-baloo_file-crash-with-corrupted-database.patch
  0003-allow-ctime-mtime-0.patch (kde#355238)
  0004-Increase-size-limit-of-baloo-index-for-64-bit-machin.patch
  (kde#364475)
  0005-Make-e.g.-Baloo-Query-thread-safe.patch
  0006-fix-typo.patch
  0007-fix-missing-m_env-nullptr-assignment.patch
  0008-Transaction-not-created-don-t-try-to-abort-them.patch
  0009-add-missing-close-env-as-pointed-out-by-Lo-c-Yhuel.patch
  (kde#353783)
  0010-Fix-sorted-insert-aka-flat_map-like-insert.patch (kde#367991)
  0011-Open-baloo-lmdb-database-read-only-beside-in-baloo_f.patch
  0012-Use-correct-config-entry-in-autostart-condition.patch
* Fri Oct  7 2016 hrvoje.senjan@gmail.com
- Baloo housekeeping:
  0001-fix-baloo_file-crash-with-corrupted-database.patch
  0003-allow-ctime-mtime-0.patch (kde#355238)
  0004-Increase-size-limit-of-baloo-index-for-64-bit-machin.patch
  (kde#364475)
  0005-Make-e.g.-Baloo-Query-thread-safe.patch
  0006-fix-typo.patch
  0007-fix-missing-m_env-nullptr-assignment.patch
  0008-Transaction-not-created-don-t-try-to-abort-them.patch
  0009-add-missing-close-env-as-pointed-out-by-Lo-c-Yhuel.patch
  (kde#353783)
  0010-Fix-sorted-insert-aka-flat_map-like-insert.patch (kde#367991)
  0011-Open-baloo-lmdb-database-read-only-beside-in-baloo_f.patch
  0012-Use-correct-config-entry-in-autostart-condition.patch
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * DocumentUrlDB::del Only assert when children of dir
    actually exist
  * Ignore malformed Queries which have a binary operator
    without first argument
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Fix using spaces in the tags kioslave (kde#349118)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Compilation fixes for Windows
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Centralize batch size in config
  * Remove code blocking indexing of text/plain files
    without .txt extension (kde#358098)
  * Check both, filename and filecontent to determine mimetype
    (kde#353512)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
- Drop upstreamed Do-not-block-indexing-of-text-plain-files-without-txt-extension.patch
* Tue Mar 22 2016 wbauer@tmo.at
- Added Do-not-block-indexing-of-text-plain-files-without-txt-extension.patch
  from upstream: fixes indexing of text/plain files without .txt
  extension (kde#358098)
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Fix several issue of mtime related search
  * PostingDB Iter: Do not assert on MDB_NOTFOUND
  * Balooctl status: Avoid showing 'Content indexing' about folders
  * StatusCommand: Show the correct status for folders
  * SearchStore: Gracefully handle empty term values (kde#356176)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Fix date filter used by timeline://
  * BalooCtl: Return after commands
  * Clean up and armour Baloo::Database::open(), handle more
    crash conditions
  * Add check in Database::open(OpenDatabase) to fail if
    db doesn't exist
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Thu Nov 12 2015 alarrosa@suse.com
- Added fix-cmakelists-comments.diff: change cmake 3.0 block
  comments to work with cmake 2.x
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Monitor lib: Use Kformat::spelloutDuration to localize
    time string
  * Use KDE_INSTALL_DBUSINTERFACEDIR to install dbus interfaces
  * UnindexedFileIndexer: Handle files that have been moved when
    baloo_file was not running
  * Remove Transaction::renameFilePath and add
    DocumentOperation for it.
  * Make constructors with a single parameter explicit
  * UnindexedFileIndexer: only index required parts of file
  * Transaction: add method to return timeInfo struct
  * Added exclude mimetypes to balooctl's config
  * Databases: Use QByteArray::fromRawData when passing data
    to a codec
  * Balooctl: Move 'status' command to its own class
  * Balooctl: Show help menu if the command is not recognized
  * Balooshow: Allow us to lookup files by their inode + devId
  * Balooctl monitor: stop if baloo dies
  * MonitorCommand: Use both the started and finished signals
  * Balooctl monitor: Move to a proper command class
  * Add dbus notification for when we start/finish
    indexing a file
  * FileIndexScheduler: Forcibly kill threads on exit
  * WriteTransaction commit: Avoid fetching the positionList
    unless required
  * WriteTransaction: Extra asserts in replaceDocument
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Fix limit/offset handling in SearchStore::exec
  * Recreate the baloo index
  * balooctl config: add options to set/view onlyBasicIndexing
  * Port balooctl check to work with new architecture (kde#353011)
  * FileContentIndexer: fix emitting filePath twice
  * UnindexedFileIterator: mtime is quint32 not quint64
  * Transaction: fix another Dbi typo
  * Transaction: Fix documentMTime() and documentCTime()
    using wrong Dbis.
  * Transaction::checkPostingDbInTermsDb: Optimize code
  * Fix dbus warnings
  * Balooctl: Add checkDb command
  * balooctl config: Add "exclude filter"
  * KF5Baloo: Make sure D-Bus interfaces are generated before they
    are used. (kde#353308)
  * Avoid using QByteArray::fromRawData
  * Remove baloo-monitor from baloo
  * TagListJob: Emit error when failed to open database
  * Do not ignore subterms if not found
  * Cleaner code for failing Baloo::File::load() on DB open fail.
  * Make balooctl use IndexerConfig instead of manipulating
    baloofilerc directly
  * Improve i18n for balooshow
  * Make balooshow fail gracefully if database cannot be opened.
  * Fail Baloo::File::load() if the Database is not open.
    (kde#353049)
  * IndexerConfig: add refresh() method
  * inotify: Do not simulate a closedWrite event after
    move without cookie
  * ExtractorProcess: Remove the extra \n at the end of
    the filePath
  * baloo_file_extractor: call QProcess::close before
    destroying the QProcess
  * baloomonitorplugin/balooctl: i18nize indexer state.
  * BalooCtl: Add a 'config' option
  * Make baloosearch more presentable
  * Remove empty EventMonitor files
  * BalooShow: Show more information when the ids do not match
  * BalooShow: When called with an id check if the id is correct
  * Add a FileInfo class
  * Add error checking in various bits so that Baloo doesn't
    crash when disabled. (kde#352454)
  * Fix Baloo not respecting "basic indexing only" config option
  * Monitor: Fetch remaining time on startup
  * Use actual method calls in MainAdaptor instead
    of QMetaObject::invokeMethod
  * Add org.kde.baloo interface to root object for
    backward compatibility
  * Fix date string displayed in address bar due to
    porting to QDate
  * Add delay after each file instead of each batch
  * Remove Qt::Widgets dependency from baloo_file
  * Remove unused code from baloo_file_extractor
  * Add baloo monitor or experimental qml plugin
  * Make "querying for remaining time" thread safe
  * kioslaves: Add missing override for virtual functions
  * Extractor: Set the applicationData after constructing the app
  * Query: Implement support for 'offset'
  * Balooctl: Add --version and --help (kde#351645)
  * Remove KAuth support to increase max inotify watches if
    count too low (kde#351602)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
- Drop upstreamed patches:
  0001-Fix-Baloo-not-respecting-basic-indexing-only-config-.patch
  0002-Add-error-checking-in-various-bits-so-that-Baloo-doe.patch
  0003-Fail-Baloo-File-load-if-the-Database-is-not-open.patch
  0004-Cleaner-code-for-failing-Baloo-File-load-on-DB-open-.patch
  0005-TagListJob-Emit-error-when-failed-to-open-database.patch
* Mon Sep 28 2015 hrvoje.senjan@gmail.com
- Added patches from upstream to resolve various issues when user
  has file indexing disabled:
  0001-Fix-Baloo-not-respecting-basic-indexing-only-config-.patch
  0002-Add-error-checking-in-various-bits-so-that-Baloo-doe.patch
  0003-Fail-Baloo-File-load-if-the-Database-is-not-open.patch
  0004-Cleaner-code-for-failing-Baloo-File-load-on-DB-open-.patch
  0005-TagListJob-Emit-error-when-failed-to-open-database.patch
* Wed Sep  9 2015 alarrosa@suse.com
- Added installed files to the %%files section to fix build
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Add org.kde.baloo interface to root object
    for backward compatibility
  * Install a fake org.kde.baloo.file.indexer.xml to
    fix compilation of plasma-desktop 5.4
  * Re-organize D-Bus interfaces
  * Use json metadata in kded plugin and fix plugin name
  * Create one Database instance per process (kde#350247)
  * Prevent baloo_file_extractor being killed while committing
  * Generate xml interface file using qt5_generate_dbus_interface
  * Baloo monitor fixes
  * Move file url export to main thread
  * Make sure cascaded configs are taken into account
  * Do not install namelink for private library
  * Install translations, spotted by Hrvoje Senjan.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
- Drop 0001-install-translations.patch, merged upstream
- Drop krunner-devel BuildRequires, no longer needed
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
- Added 0001-install-translations.patch from upstream
* Sun Jul 26 2015 hrvoje.senjan@gmail.com
- Fix Oboletes/Provides versions regarding Leap versioning
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
- Drop 0001-Revert-BasicIndexingQueue-Use-xapian-slots-to-fetch-.patch,
  merged upstream
* Sat May  2 2015 hrvoje.senjan@gmail.com
- Added 0001-Revert-BasicIndexingQueue-Use-xapian-slots-to-fetch-.patch
  from upstream
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
- Let file and tools subpackages Obsolete KDE4 variants for
  openSUSE > 13.2
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Raise required extra-cmake-modules version to 1.2.0
- Added kdbusaddons-devel BuildRequires
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Added baselibs.conf
- Drop kcmutils-devel BuildRequires
- Add recommends for lang subpackage
- New libKF5Baloo1 shlib replaces libKF5BalooNaturalQueryParser1,
  libKF5BalooFiles1 and libKF5BalooCore1
- Remove not needed Obsoletes
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
- (Build)Require equal version of kfilemetadata5-devel
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * Escape dots in exclude filters, kde#339908
  * BasicIQ: Fix broken indexing on file modifications when
    file exists
  * Fix build with Qt 5.4
  * BasicIQ: Fetch the id before indexing it
  * Enforce a maxiumum term size of 25
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor API adjustements since previous snapshot
- Install translations
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140911 (rb92aa3b):
  * Use QPluginLoader instead of KService.
  * New naturalqueryparser library
  * API cleanups
  * Various bugfixes
  * Added QML components
- Drop kservice-devel BuildRequires, per upstream changes
- Added pkgconfig(Qt5Quick) BuildRequires
* Sun Aug 10 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Sun Jul 27 2014 hrvoje.senjan@gmail.com
- Added libQt5Sql5-sqlite Requires to file subpackage
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Thu Jun  5 2014 hrvoje.senjan@gmail.com
- Activate baloo5 package
